@@ -12,6 +12,7 @@
 """
 __author__ = 'liaozhaoyan'
 
-from soda import Path, Root, Fragment, Literal, XMLDeclaration
-from .svg import eTag
+from .tags import Tag, Root, Fragment, Literal, XMLDeclaration
+from .paths import Path
 from .packer import Packer
+from .flame import Flame
